.. _tool-example:

tellcore_tool (example)
=======================

The example below is an implementation of tdtool similar to the one included in
the official Telldus Core distribution.

.. literalinclude:: ../bin/tellcore_tool
